@@ -1,6 +1,7 @@
 import sys
 import csv
 import os
+import re
 import json
 import shutil
 import subprocess
@@ -548,7 +549,7 @@ def run(parser: Any, **kwargs: Any) -> None:
             print('binding not needed...')
 
             job: Dict[str, Any] = {
-                'shell_cmd': f'{root_path}/src/run_phbr.py predict -j {input_file} -o {result_dir_phbr.resolve()}/{curr_job_id} -f json',
+                "shell_cmd": f"{root_path}/src/run_phbr.py predict -j {input_file} -d {data['metadata']['output_dir']} -o {result_dir_phbr.resolve()}/{curr_job_id} -f json",
                 'job_id': curr_job_id,
                 'job_type': 'predict',
                 'depends_on_job_ids': [],
@@ -644,8 +645,7 @@ def run(parser: Any, **kwargs: Any) -> None:
             #     source {root_path}/setup_mhci_env.sh
             #     python3 $TCELL_CLASS_I_PATH/src/tcell_mhci.py -j {phbr_input_file} --split --split-dir={tmpdir} --keep-empty-row
             # """) 
-
-            cmd = f"{root_path}/src/run_phbr.py predict -j {phbr_mhci_input_file} -o {result_dir_phbr.resolve()}/{mhci_job_id} -f json"
+            cmd = f"{root_path}/src/run_phbr.py predict -j {phbr_mhci_input_file} -d {data['metadata']['output_dir']} -o {result_dir_phbr.resolve()}/{mhci_job_id} -f json"
 
             phbr_job = {
                 'shell_cmd': cmd,
@@ -687,7 +687,7 @@ def run(parser: Any, **kwargs: Any) -> None:
             print('binding not needed...')
 
             job: Dict[str, Any] = {
-                'shell_cmd': f'{root_path}/src/run_phbr.py predict -j {input_file} -o {result_dir_phbr.resolve()}/{curr_job_id} -f json',
+                "shell_cmd": f"{root_path}/src/run_phbr.py predict -j {input_file} -d {data['metadata']['output_dir']} -o {result_dir_phbr.resolve()}/{curr_job_id} -f json",
                 'job_id': curr_job_id,
                 'job_type': 'predict',
                 'depends_on_job_ids': [],
@@ -743,6 +743,8 @@ def run(parser: Any, **kwargs: Any) -> None:
                     # Update dependencies for aggregate job
                     job_start = curr_job_id - len(mhcii_job_description) + 1
                     job['depends_on_job_ids'] = list(range(job_start, curr_job_id))
+
+                
                 job_description.append(job)
                 curr_job_id += 1
 
@@ -782,7 +784,7 @@ def run(parser: Any, **kwargs: Any) -> None:
                 json.dump(serializable_data, f, indent=2)
                 print(f"Created file with phbr_input at: {phbr_mhcii_input_file}")
 
-            cmd = f"{root_path}/src/run_phbr.py predict -j {phbr_mhcii_input_file} -o {result_dir_phbr.resolve()}/{curr_job_id} -f json"
+            cmd = f"{root_path}/src/run_phbr.py predict -j {phbr_mhcii_input_file} -d {data['metadata']['output_dir']} -o {result_dir_phbr.resolve()}/{curr_job_id} -f json"
 
             phbr_job = {
                 'shell_cmd': cmd,
