@@ -137,6 +137,7 @@ def mhc_binding_result_json2tsv(params_dir: Path, t_cell_class: TCellClass, is_a
 
         if is_aggregated_result:
            new_result_file = tempfile.NamedTemporaryFile(mode='w', suffix='.tsv', delete=False).name
+           print('Creating temporary file: ', new_result_file)
 
         with open(new_result_file, 'w', newline='') as f_out:
             writer = csv.writer(f_out, delimiter='\t')
@@ -149,18 +150,18 @@ def mhc_binding_result_json2tsv(params_dir: Path, t_cell_class: TCellClass, is_a
     return new_result_file
 
 
-def create_peptide_and_sequence_files(df: pd.DataFrame) -> Tuple[str, str]:
+def create_peptide_and_sequence_files(df: pd.DataFrame, output_dir: str) -> Tuple[str, str]:
     peptide_table_path = None
     sequence_table_path = None
 
     # Create a temporary file for peptide_table
-    with tempfile.NamedTemporaryFile(mode='w+', suffix='.tsv', delete=False) as tmpfile:
+    with tempfile.NamedTemporaryFile(mode='w+', suffix='.tsv', delete=False, dir=output_dir) as tmpfile:
         peptide_df = df['peptide_table'].rename(columns={'sequence_number': 'seq #'})
         peptide_df.to_csv(tmpfile.name, index=False, sep="\t")
         peptide_table_path = tmpfile.name  # Store the file path if needed
 
     # Create a temporary file for input_sequence_table
-    with tempfile.NamedTemporaryFile(mode='w+', suffix='.tsv', delete=False) as tmpfile:
+    with tempfile.NamedTemporaryFile(mode='w+', suffix='.tsv', delete=False, dir=output_dir) as tmpfile:
         # Renaming column 'sequence_number' to 'seq #' in input_sequence_table
         input_seq_df = df['input_sequence_table'].rename(columns={'sequence_number': 'seq #'})
         input_seq_df.to_csv(tmpfile.name, index=False, sep="\t")
@@ -203,6 +204,7 @@ def mhci_to_phbr(data: Dict[str, Any], parser: PhbrArgumentParser) -> None:
     mut_pos_col = data.get('mutation_position_colname')
     mut_pos = data.get('mutation_position')
     output_file = data.get('output_file')
+    output_dir = data['metadata'].get('output_dir')
     mhci_config = data['class_i']
     root_path = parser.PROJECT_ROOT_PATH
     mhc_args = []
@@ -222,7 +224,7 @@ def mhci_to_phbr(data: Dict[str, Any], parser: PhbrArgumentParser) -> None:
     '''
     if 'mhc_result_uri' in data:
         df = uri_to_df(data['mhc_result_uri'])
-        peptide_table_path, sequence_table_path = create_peptide_and_sequence_files(df)
+        peptide_table_path, sequence_table_path = create_peptide_and_sequence_files(df, output_dir)
 
         # Extract unique values from the 'allele' column
         unique_alleles = df['peptide_table']['allele'].unique()
@@ -267,9 +269,15 @@ def mhci_to_phbr(data: Dict[str, Any], parser: PhbrArgumentParser) -> None:
     Convert MHCI binding result to PHBR input format.
     * Call mhc2phbr.py to convert MHCI binding result to PHBR input format.
     '''
-    tmp_mhc_pred_file = tempfile.NamedTemporaryFile(prefix="phbr-input-", delete=False)
+    tmp_mhc_pred_file = tempfile.NamedTemporaryFile(prefix="phbr-input-", delete=False, dir=output_dir)
     mhc2phbr_fpath = parser.find_file_path(start_dir=root_path, filename='mhc2phbr.py')
 
+    # print('--------------------------------------------------')
+    # print('tmp_mhc_pred_file: ', tmp_mhc_pred_file)
+    # print('tmp_mhc_pred_file.name: ', tmp_mhc_pred_file.name)
+    # print('--------------------------------------------------')
+    # sys.exit()
+
     # Specify --rank-colname
     # NOTE: if 'netmhcpan percentile' is not found, then use 'percentile' 
     #       as the default rank_colname
@@ -360,6 +368,7 @@ def mhcii_to_phbr(data: Dict[str, Any], parser: PhbrArgumentParser) -> None:
     mut_pos_col = data.get('mutation_position_colname')
     mut_pos = data.get('mutation_position')
     output_file = data.get('output_file')
+    output_dir = data['metadata'].get('output_dir')
     mhcii_config = data['class_ii']
     root_path = parser.PROJECT_ROOT_PATH
     mhc_args = []
@@ -379,7 +388,7 @@ def mhcii_to_phbr(data: Dict[str, Any], parser: PhbrArgumentParser) -> None:
     '''
     if 'mhc_result_uri' in data:
         df = uri_to_df(data['mhc_result_uri'])
-        peptide_table_path, sequence_table_path = create_peptide_and_sequence_files(df)
+        peptide_table_path, sequence_table_path = create_peptide_and_sequence_files(df, output_dir)
 
         # Extract unique values from the 'allele' column
         unique_alleles = df['peptide_table']['allele'].unique()
@@ -424,7 +433,7 @@ def mhcii_to_phbr(data: Dict[str, Any], parser: PhbrArgumentParser) -> None:
     Convert MHCII binding result to PHBR input format.
     * Call mhc2phbr.py to convert MHCII binding result to PHBR input format.
     '''
-    tmp_mhc_pred_file = tempfile.NamedTemporaryFile(prefix="phbr-input-", delete=False)
+    tmp_mhc_pred_file = tempfile.NamedTemporaryFile(prefix="phbr-input-", delete=False, dir=output_dir)
     mhc2phbr_fpath = parser.find_file_path(start_dir=root_path, filename='mhc2phbr.py')
     
     # Specify --rank-colname
@@ -601,10 +610,18 @@ def main() -> None:
 
         final_output_file = data['output_file'] = output_file
 
+         # Create a temporary directory for temporary files
+        if args.output_dir != '/tmp':
+            tmp_output_dir = args.output_dir + '/phbr/tmp'
+            os.makedirs(tmp_output_dir, exist_ok=True)
+        else:
+            tmp_output_dir = args.output_dir
+
         # Add metadata
         data['metadata'] = {
             'subcommand': args.subcommand,
             'root_path': parser.PROJECT_ROOT_PATH,
+            'output_dir': tmp_output_dir,
         }
 
         # NOTE: Turn "input_neoepitopes" into "mhc_sequence_tsv"
@@ -613,8 +630,7 @@ def main() -> None:
             df = df.rename(columns=lambda x: 'sequence' if 'peptide' in x.lower() else x)
             df.insert(0, 'seq #', range(1, len(df) + 1))
 
-            # Create a temporary file
-            with tempfile.NamedTemporaryFile(mode='w+', suffix='.tsv', delete=False) as tmp_file:
+            with tempfile.NamedTemporaryFile(mode='w+', suffix='.tsv', delete=False, dir=tmp_output_dir) as tmp_file:
                 df.to_csv(tmp_file.name, index=False, sep='\t')
                 print(f"Temporary file created at: {tmp_file.name}")
             
@@ -627,8 +643,8 @@ def main() -> None:
         if 'class_i' in data and 'class_ii' in data:
             print("Processing combined MHCI and MHCII input...")
             # Create temporary files for individual outputs
-            tmp_phbr_mhci_output = tempfile.NamedTemporaryFile(prefix="phbr-mhci-output-", suffix=".tsv", delete=False).name
-            tmp_phbr_mhcii_output = tempfile.NamedTemporaryFile(prefix="phbr-mhcii-output-", suffix=".tsv", delete=False).name
+            tmp_phbr_mhci_output = tempfile.NamedTemporaryFile(prefix="phbr-mhci-output-", suffix=".tsv", delete=False, dir=tmp_output_dir).name
+            tmp_phbr_mhcii_output = tempfile.NamedTemporaryFile(prefix="phbr-mhcii-output-", suffix=".tsv", delete=False, dir=tmp_output_dir).name
 
             data['output_file'] = tmp_phbr_mhci_output
 
